// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com  
// Apdo. 964-1250 Escazu, San Jose, Costa Rica
// dedicado a Jesus y Maria...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho... 18 octubre 2016
//                
// Mis dibujos estan en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY
//      
// DTSG DuchaTermicaSalidaGravitatoria
// El archivo dibuja una ducha caliente para uso domestico, 
// es muy poco flexible pero incluye una macro para modificar
// texturas y unas pocas caracteristicas. Es compatible con POV-Ray 3.1.
//
// La macro principal tiene solo un parametro.   
// #macro DTSG_Ducha( FraccionPerilla )
//      FraccionPerilla         : Fraccion propia con signo, para desplazar la
//              perilla de control respecto a su posicion central en 0.0. 
//
// La siguiente macro permite mayor control de las caracteristicas.
// #macro DTSG_DuchaTermicaSalidaGravitatoria( FraccionPerilla,
//                AltoTotal, FraccionSuperior, DiametroSuperior,
//                FraccionInferior, DiametroInferior,
//                AnguloManguerita, DiametroTubo,
//                MaterialPrincipal, MaterialSuperior,
//                MaterialSalida )
//      FraccionPerilla         : Fraccion propia con signo, para desplazar la
//              perilla de control respecto a su posicion central en 0.0. 
//      AltoTotal               : Alto total ocupado por la ducha.
//              Valor por defecto 109*L.
//      FraccionSuperior        : Fraccion propia del total ocupado por la
//              seccion superior de la ducha con entrada de cables electricos.
//              Valor por defecto 0.270.
//      DiametroSuperior        : Diametro del cilindro imaginario de union 
//              del sector superior de la ducha respecto al sector medio.
//              Valor por defecto 58*L.
//      FraccionInferior        : Fraccion propia del total ocupado por la
//              seccion inferior de la ducha para salida del chorro de agua.
//              Valor por defecto 0.285.
//      DiametroInferior        : Diametro del cilindro imaginario de union 
//              del sector inferior de la ducha respecto al sector medio.
//              Valor por defecto 89*L.
//      AnguloManguerita        : Posicion angular de la salida para una manguerita
//              adicional a la ducha. El angulo se mide respecto a la posicion frontal.
//              Valor por defecto 105.
//      DiametroTubo            : Diametro del tubo principal para la entrada de agua.
//              Valor por defecto 13*L.
//      MaterialPrincipal       : Material principal para la ducha.
//              Valor por defecto DTSG_MaterialPrincipal.
//      MaterialSuperior        : Material a aplicar en la seccion superior de la ducha.
//              Valor por defecto DTSG_MaterialSuperior.
//      MaterialSalida          : Material a aplicar a la salida del chorro de agua.
//              Valor por defecto DTSG_MaterialSalida.
//      
// La ducha con sus valores por defecto se encuentra completamente contenida en:   
//      Punto Minimo    = <-47,  0,-48>*L
//      Punto Maximo    = < 47,109, 47>*L  
// El alto concuerda con el parametro AltoTotal, el diametro real sera ligeramente superior
// a DiametroInferior. 
// La salida de agua apunta hacia Y-, y las entradas de agua y cables hacia X-. El eje
// principal de la ducha se encuentra centrado sobre el eje Y, reposando directamente 
// encima del plano XZ.
//
// Estas son variables predefinidas o generadas en el
// interior de las macros que no deberian modificarse directamente.
// Si quiere cambiarlas, recurra a los modificadores.  
// #declare DTSG_DefaultMaterialPrincipal       
//      Material principal para la ducha.
// #declare DTSG_DefaultMaterialSuperior        
//      Material a aplicar a la seccion superior de la ducha.
// #declare DTSG_DefaultMaterialSalida        
//      Material a aplicar a la salida del chorro de agua.
//
// Los siguientes son los modificadores
// aplicables y redefinibles por el usuario (si se indica es default)   
// #declare DTSG_MaterialPrincipal              = material { ... }       
//      Material principal para la ducha.
// #declare DTSG_MaterialSuperior               = material { ... }
//      Material a aplicar a la seccion superior de la ducha.
// #declare DTSG_MaterialSalida                 = material { ... }
//      Material a aplicar a la salida del chorro de agua.
//        
// Para colocarlo simplemente
// #include "DTSG.inc" 
// material                     {
//   DTSG_DuchaTermicaSalidaGravitatoria( 0.0, 
//                0.109, 0.270, 0.058, 0.285, 0.089, 105, 0.013,
//                DTSG_MaterialPrincipal, DTSG_MaterialSuperior,
//                DTSG_MaterialSalida )  
// }
//                                 
// Ejemplo con la macro detallada, mismo objeto default
// #include "DTSG.inc"   
// object                       {
//   DTSG_PlanchaCuidadoMaterialCaliente( 0, off, 0.140, 0.007, 0.020, 2.86, 0.084, 0.025,
//        DTSG_MaterialPrincipal, DTSG_MaterialMetalico,
//        DTSG_MaterialMetalicoCaliente, DTSG_MaterialBaseAgarradera )  
// }
//        
// Con modificadores
// #include "DTSG.inc"
// #include "textures.inc"
// #declare DTSG_MaterialPrincipal   = material { textures { PinkAlabaster } }
// object        { DTSG_Ducha( 0.0 ) }
//
#if ( version >= 3.7 )
  #version 3.7; 
#end

global_settings { assumed_gamma 1.0 }

#include "colors.inc"

#declare OjoAbsoluto            = 256;
#declare VecesCentroAbsoluto    = 10;     
#declare L                      = 0.001;
camera {
        location  <   0,  0, -( VecesCentroAbsoluto+1 )*OjoAbsoluto >*L
        direction z
        sky       y
        angle     38.74
//        look_at  <   0,  0, -VecesCentroAbsoluto*OjoAbsoluto >*L
}         
light_source    {
         <  500  ,  500   , -3000 >*L
         White*0.8
}
light_source    {
         <-1000  ,- 500   , -3000 >*L
         White*0.8
}
background      {
         Gray50
}    

#include "DTSG.inc"

#declare FactorAcercamiento             = 12; 
 
object                          {
  DTSG_Ducha( 1.0 )        
  translate         -0.052*y
  translate       -( VecesCentroAbsoluto+1 )*( FactorAcercamiento-1 )
                        /( FactorAcercamiento )*OjoAbsoluto*L*z      
}

