// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com  
// Apdo. 964-1250 Escazu, San Jose, Costa Rica
// dedicado a Jesus y Maria...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho... 14 diciembre 2016
//                
// Mis dibujos estan en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY
//     
// JHSV JuegoHomeSigloVeintiuno
// El archivo dibuja un tablero para el tradicional juego Home-Parchis, con relieve
// plastico para facilitar el tiro del dado y la colocacion de las piezas
// por ninos menores. El original se baso en un modelo para
// la serie Paw Patrol de Nickelodeon producto marca Cardinal Industries. 
// Se elimino intencionalmente las referencias publicitarias para
// facilitar la aplicacion legal de la patente CC-LGPL.
// El mecanismo de tirada del dado consiste en una semiesfera en un compartimento
// plastico y una plaquita metalica que sirve de rebote y "arroja" el dado en su interior.
// Es muy poco flexible. Es compatible con POVRay 3.1.
//
// La macro principal tiene tres parametros. 
// #macro JHSV_Home( Semilla, NumeroDado, FraccionPresionar )   
//      Semilla                 : Para semilla del generador aleatorio.
//      NumeroDado              : Cara del lado resultado de la tirada.
//      FraccionPresionar       : Fraccion propia para el mecanismo de tirada de dado.
//              Use 0.0 para liberar y 1.0 para completamente presionado.
//
// La siguiente macro permite mayor versatilidad. Debido al efecto de la semilla,
// es de esperar que la posicion del dado varie respecto a la macro anterior.
// #macro JHSV_JuegoHomeSigloVeintiuno( NumeroDado, FraccionPresionar,
//                LadoFundamental, CurvaturaFundamental,
//                GruesoPlastico, GruesoMetal,
//                DiametroPosicion, AlturaPosicion, LadoDado,
//                RotateDado, TranslateDado,
//                MaterialPrincipal, MaterialTablero, MaterialMetalico,
//                MaterialDado, MaterialSalida, MaterialMeta )
//      NumeroDado              : Cara del lado resultado de la tirada.
//      FraccionPresionar       : Fraccion propia para el mecanismo de tirada de dado.
//              Use 0.0 para liberar y 1.0 para completamente presionado.   
//      LadoFundamental         : Determina el lado del cuadrado que delimita la figura.
//              Valor por defecto 187*L.
//      CurvaturaFundamental    : Curvatura de las esquinas como diametro del circulo.
//              Deberia ser algo menor a sqrt(2)*LadoFundamental.
//              Valor por defecto 230*L.
//      GruesoPlastico          : Grueso del plastico utilizado. 
//              Valor por defecto 1.7*L.
//      GruesoMetal             : Grueso del metal de rebote en la estructura para tirar
//              el dado. Valor por defecto 0.3*L.
//      DiametroPosicion        : Diametro de los cilindros para ubicar fichas.
//              Valor por defecto 11.0*L.
//      AlturaPosicion          : Altura de los cilindros para ubicar fichas.
//              Valor por defecto 4.5*L.
//      LadoDado                : Lado del cubo para dibujar el dado.
//              Valor por defecto 7*L.
//      RotateDado              : Se aplicara este rotate al origen antes de ubicar el dado.
//              Utilice k*y si no quiere variar el resultado NumeroDado.
//      TranslateDado           : Luego de ubicar el dado al centro de la placa
//              metalica (incluye el efecto de FraccionPresionar), se aplicara
//              un translate con este TranslateDado.
//      MaterialPrincipal       : Material principal a aplicar a la estructura.
//              Valor por defecto JHSV_MaterialPrincipal.
//      MaterialTablero         : Material de la superficie impresa del tablero.
//              Valor por defecto JHSV_MaterialTablero.                     
//      MaterialMetalico        : Material para la plaquita metalica de rebote del dado.
//              Valor por defecto JHSV_MaterialMetalico.
//      MaterialDado            : Material para la superficie del dado (sin los puntos).
//              Valor por defecto JHSV_MaterialDado.
//      MaterialSalida          : Material para la casilla de salida de Home-Parchis.
//              Valor por defecto JHSV_MaterialSalida.
//      MaterialMeta            : Material para la casilla de meta de Home-Parchis.
//              Valor por defecto JHSV_MaterialMeta.       
// 
// Incluye una macro para dibujar un dado.           
// #macro JHSV_Dado( LadoDado, MaterialDado )
//      LadoDado                : Lado del cubo para dibujar el dado.
//              Valor por defecto 7*L.
//      MaterialDado            : Material para la superficie del dado (sin los puntos).
//              Valor por defecto JHSV_MaterialDado.
//  
// Fichas independientes del tablero, pueden dibujarse con la siguiente macro.  
// Tomar en cuenta que las fichas se dibujan con un radio GruesoPlastico menor al
// tamano ajustado.
// #macro JHSV_Ficha( DiametroPosicion, AlturaPosicion,
//                        GruesoPlastico, IndiceColor )
//      DiametroPosicion        : Diametro de los cilindros para ubicar fichas.
//              Valor por defecto 11.0*L.
//      AlturaPosicion          : Altura de los cilindros para ubicar fichas.
//              Valor por defecto 4.5*L.
//      GruesoPlastico          : Grueso del plastico utilizado. 
//              Valor por defecto 1.7*L.                                        
//      IndiceColor             : Indice entero de color. Puede tomar los valores
//              JHSV_FichaAzul, JHSV_FichaVerde, JHSV_FichaRoja y JHSV_FichaAmarilla.
// 
// El tablero de juego se encuentra contenido (FraccionPresionar nulo)
// entre las siguientes coordenadas:
//      Minimo  = <-LadoFundamental/2,0,+LadoFundamental/2>
//      Maximo  = <+LadoFundamental/2,+0.110*LadoFundamental+5*GruesoPlastico,
//                 +LadoFundamental/2> 
// O con valores por defecto:
//      Minimo  = <-93.5,   0.0,-93.5 >*L
//      Maximo  = < 93.5,  29.1, 93.5 >*L 
// El tablero descansa centrado sobre el plano XZ, gravedad Y-.    
//
// Estas son variables predefinidas o generadas en el
// interna de las macros que no deberian modificarse directamente.
// Si quiere cambiarlas, recurra a los modificadores.  
// #declare JHSV_MacroTranslateDado   
//      Ubicacion del dado segun resultado dado por la macro a partir del origen.
//      Incluye el efecto del parametro "TranslateDado", y se calcula aunque
//      no se dibuje el dado del todo.
// #declare JHSV_TotalFichas                = 16;
//      Tamano de arreglo de fichas JHSV_ArregloFichas.
// #declare JHSV_FichaAzul                  = 0; 
//      Clave indice para ficha color azul.
// #declare JHSV_FichaVerde                 = 1;
//      Clave indice para ficha color verde.
// #declare JHSV_FichaRoja                  = 2;
//      Clave indice para ficha color rojo.
// #declare JHSV_FichaAmarilla              = 3;
//      Clave indice para ficha color amarillo.
// #declare JHSV_CasillaSalida              = 0;
//      Clave indice para casilla de salida de juego.
// #declare JHSV_CasillaActiva              = 1;
//      Clave indice para casilla de salida normal.
// #declare JHSV_CasillaMeta                = 2;
//      Clave indice para casilla de final de juego.
// #declare JHSV_DefaultMaterialPrincipal        
//      Material principal a aplicar a la estructura.
// #declare JHSV_DefaultMaterialTablero         
//      Material de la superficie impresa del tablero.
// #declare JHSV_DefaultMaterialMetalico        
//      Material para la plaquita metalica de rebote del dado.
// #declare JHSV_DefaultMaterialDado            
//      Material para la superficie del dado (sin los puntos).
// #declare JHSV_DefaultMaterialSalida          
//      Material para la casilla de salida de Home-Parchis.
// #declare JHSV_DefaultMaterialMeta            
//      Material para la casilla de meta de Home-Parchis.
//
// Los siguientes son los modificadores
// aplicables y redefinibles por el usuario (si se indica es default)   
// #declare JHSV_ArregloFichas             = array [ JHSV_TotalFichas ]
//      de vectores 4D de fichas dados como
//      < Visibilidad, Color, Estado, Posicion >   
//          Visibilidad     : "on" la ficha es visible, "off" invisible.
//          Color           : Indice de color (no modificar). Los colores
//              aparecen en el siguiente orden: cuatro JHSV_FichaAmarilla,
//              cuatro JHSV_FichaAzul, cuatro JHSV_FichaVerde y 
//              las ultimas cuatro JHSV_FichaRoja.
//          Estado          : Tres estados posibles como numero entero.
//              JHSV_CasillaSalida, JHSV_CasillaActiva y JHSV_CasillaMeta,
//              para indicar en cual de las tres regiones se ubica la ficha.
//          Posicion        : Las casillas de Salida y de Meta se numeran
//              desde 0 al 3. Siguiendo el sentido horario visto desde arriba,
//              y de afuera hacia adentro.
//              Para las casillas normales, la posicion 0 de cualquier color
//              es la casilla blanca de su propia esquina,
//              la numeracion sigue el sentido horario desde 0 hasta 27.
// #declare JHSV_ColorPuntoDado             = Black;
//      Color por diferencia del punto del dado.
// #declare JHSV_DadoVisible                = on;
//      "on" activa el dibujo del dado. "off" no dibuja el dado.
// #declare JHSV_PigmentAmarillo            = pigment { Yellow  }   
//      Pigmento a aplicar a las fichas con indice JHSV_FichaAmarilla                                           
// #declare JHSV_PigmentAzul                = pigment { Blue    }
//      Pigmento a aplicar a las fichas con indice JHSV_FichaAzul                                               
// #declare JHSV_PigmentVerde               = pigment { Green   }
//      Pigmento a aplicar a las fichas con indice JHSV_FichaVerde                                              
// #declare JHSV_PigmentRojo                = pigment { Red     } 
//      Pigmento a aplicar a las fichas con indice JHSV_FichaRoja                                             
// #declare JHSV_MaterialPrincipal          = material { ... }     
//      Material principal a aplicar a la estructura.
// #declare JHSV_MaterialTablero            = material { ... }    
//      Material de la superficie impresa del tablero.
// #declare JHSV_MaterialMetalico           = material { ... }   
//      Material para la plaquita metalica de rebote del dado.
// #declare JHSV_MaterialDado               = material { ... }    
//      Material para la superficie del dado (sin los puntos).
// #declare JHSV_MaterialSalida             = material { ... }     
//      Material para la casilla de salida de Home-Parchis.
// #declare JHSV_MaterialMeta               = material { ... }     
//      Material para la casilla de meta de Home-Parchis.
//        
// Para colocarlo simplemente
// #include "JHSV.inc" 
// object { JHSV_Home(1000, 5, 0.0) }
//                                  
// Ejemplo con la macro de texturas, mismo objeto default
// #include "JHSV.inc"
// object                       {   
//   JHSV_JuegoHomeSigloVeintiuno( 5, 0.0,    
//            0.187, 0.230, 0.0017, 0.0003, 0.011, 0.0045, 0.007, 0, 0,
//            JHSV_MaterialPrincipal, JHSV_MaterialTablero,
//            JHSV_MaterialMetalico, JHSV_MaterialDado, 
//            JHSV_MaterialSalida, JHSV_MaterialMeta )
// }
//        
// Con modificadores. Colocamos la Ficha 0 en la meta y la Ficha 1 la desaparecemos,
// note que no cambiamos el indice de color que es la componente y.
// #include "JHSV.inc"
// #include "textures.inc"
// #declare JHSV_MaterialPrincipal   = material { texture { PinkAlabaster } } 
// #declare JHSV_ArregloFichas[0]    = <on,JHSV_ArregloFichas[0].y,JHSV_CasillaMeta,2>;
// #declare JHSV_ArregloFichas[1]    = off*x+JHSV_ArregloFichas[1]*(y+z+t);
// object        { JHSV_Home(1000,5,0.0) }
// 

#if ( version >= 3.7 )
  #version 3.7; 
#end

global_settings { assumed_gamma 1.0 }

#include "glass.inc"
#include "colors.inc"

#declare OjoAbsoluto            = 256;
#declare VecesCentroAbsoluto    = 10;     
#declare L                      = 0.001;
camera {
        location  <   0,  0, -( VecesCentroAbsoluto+1 )*OjoAbsoluto >*L
        direction z
        sky       y
        angle     38.74
//        look_at  <   0,  0, -VecesCentroAbsoluto*OjoAbsoluto >*L
}         
light_source    {
         < 500  , 500   , -3000 >*L
         White
}
background      {
         Gray50
}    

#include "JHSV.inc"     

#declare FactorAcercamiento             = 7;
  
object                                  {
  JHSV_Home( 12300, 2, 0.0 )        
  rotate            -90*x
  translate       -( VecesCentroAbsoluto+1 )*( FactorAcercamiento-1 )
                        /( FactorAcercamiento )*OjoAbsoluto*L*z      
}

